Module allocators

Allocators provided by stabby

Structs

RustAlloc
Rust’s GlobalAlloc, annotating its yielded pointers in such a way that the allocated pointers can be safely freed from other binaries.