Struct RustAlloc

#[repr(C)]
pub struct RustAlloc { /* private fields */ }
Rust’s GlobalAlloc, annotating its yielded pointers in such a way that the allocated pointers can be safely freed from other binaries.

Implementations

Source

impl RustAlloc
where Struct<[u8; 0]>: IStable, [u8; 0]: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for RustAlloc is smaller or equal to that Rust would have generated for it.

Source

impl RustAlloc

pub const fn new() -> Self

Constructs the allocator.