Struct Box

#[repr(C)]
pub struct Box<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }
An ABI-stable Box, provided Alloc is ABI-stable.

Implementations

Source

impl<T, Alloc: IAlloc> Box<T, Alloc>
where Struct<AllocPtr<T, Alloc>>: IStable, AllocPtr<T, Alloc>: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for Box is smaller or equal to that Rust would have generated for it.

Source

impl<T> Box<T>

pub unsafe fn make<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, ) -> Result<Self, Box<MaybeUninit<T>>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

If the allocation fails, the constructor will not be run.

Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Errors

Returns the uninitialized allocation if the constructor declares a failure.

Panics

If the allocator fails to provide an appropriate allocation.

pub fn new(value: T) -> Self

Attempts to allocate Self and store value in it.

Panics

If the allocator fails to provide an appropriate allocation.

Source

impl<T, Alloc: IAlloc> Box<T, Alloc>

pub unsafe fn try_make_in<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, alloc: Alloc, ) -> Result<Self, Result<Box<MaybeUninit<T>, Alloc>, (F, Alloc)>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

If the constructor panics, the allocated memory will be leaked.

Errors
  • Returns the constructor and the allocator in case of allocation failure.
  • Returns the uninitialized allocated memory if constructor fails.
Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Notes

Note that the allocation may or may not be zeroed.

pub fn try_new_in(value: T, alloc: Alloc) -> Result<Self, (T, Alloc)>

Attempts to allocate a Self and store value in it

Errors

Returns value and the allocator in case of failure.

pub unsafe fn make_in<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, alloc: Alloc, ) -> Result<Self, Box<MaybeUninit<T>, Alloc>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

Errors

Returns the uninitialized allocated memory if constructor fails.

Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Panics

If the allocator fails to provide an appropriate allocation.

pub fn new_in(value: T, alloc: Alloc) -> Self

Attempts to allocate Self and store value in it.

Panics

If the allocator fails to provide an appropriate allocation.

pub fn into_inner(this: Self) -> T

Extracts the value from the allocation, freeing said allocation.

pub const fn into_raw(this: Self) -> AllocPtr<T, Alloc>

Returns the pointer to the inner raw allocation, leaking this.

Note that the pointer may be dangling if T is zero-sized.

pub const unsafe fn from_raw(this: AllocPtr<T, Alloc>) -> Self

Constructs Self from a raw allocation.

Safety

No other container must own (even partially) this.