#[repr(C)]pub struct AllocPrefix<Alloc> {
pub strong: AtomicUsize,
pub weak: AtomicUsize,
pub capacity: AtomicUsize,
pub origin: NonNull<()>,
pub alloc: MaybeUninit<Alloc>,
}Expand description
The prefix common to all allocations in stabby::alloc.
This allows reuse of allocations when converting between container types.
Fields
strong: AtomicUsizeThe strong count for reference counted types.
weak: AtomicUsizeThe weak count for reference counted types.
capacity: AtomicUsizeA slot to store a vector’s capacity when it’s turned into a boxed/arced slice.
origin: NonNull<()>The origin of the prefix
alloc: MaybeUninit<Alloc>A slot for the allocator.
Implementations
Sourceimpl<Alloc> AllocPrefix<Alloc>where
Struct<FieldPair<FieldPair<FieldPair<FieldPair<AtomicUsize, AtomicUsize>, AtomicUsize>, NonNull<()>>, MaybeUninit<Alloc>>>: IStable,
MaybeUninit<Alloc>: IStable,
NonNull<()>: IStable,
AtomicUsize: IStable,
impl<Alloc> AllocPrefix<Alloc>where
Struct<FieldPair<FieldPair<FieldPair<FieldPair<AtomicUsize, AtomicUsize>, AtomicUsize>, NonNull<()>>, MaybeUninit<Alloc>>>: IStable,
MaybeUninit<Alloc>: IStable,
NonNull<()>: IStable,
AtomicUsize: IStable,
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for AllocPrefix is smaller or equal to that Rust would have generated for it.