#[repr(C)]pub struct Layout {
pub size: usize,
pub align: usize,
}Expand description
ABI-stable equivalent of std::mem::Layout
Fields
size: usizeThe expected size of the allocation.
align: usizeThe expected alignment of the allocation.
Implementations
Sourceimpl Layout
impl Layout
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for Layout is smaller or equal to that Rust would have generated for it.
Sourceimpl Layout
impl Layout
Sourcepub const fn array<T: Sized>(n: usize) -> Self
pub const fn array<T: Sized>(n: usize) -> Self
Returns the Layout corresponding to [T; n].
Note that while this ensures that even if T’s size is not a multiple of its alignment,
the layout will have sufficient memory to store n of T in an aligned fashion.
Sourcepub const fn concat(self, other: Self) -> Self
pub const fn concat(self, other: Self) -> Self
Concatenates a layout to self, ensuring that alignment padding is taken into account.
Sourcepub fn next_matching<T>(self, ptr: *mut T) -> *mut T
pub fn next_matching<T>(self, ptr: *mut T) -> *mut T
Returns the first pointer where output >= ptr such that output % self.align == 0.