Struct Arc

#[repr(C)]
pub struct Arc<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }
alloc::sync::Arc, but ABI-stable.

Implementations

Source

impl<T, Alloc: IAlloc> Arc<T, Alloc>
where Struct<AllocPtr<T, Alloc>>: IStable, AllocPtr<T, Alloc>: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for Arc is smaller or equal to that Rust would have generated for it.

Source

impl<T> Arc<T>

pub unsafe fn make<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, ) -> Result<Self, Arc<MaybeUninit<T>>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

If the allocation fails, the constructor will not be run.

Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Errors

Returns the uninitialized allocation if the constructor declares a failure.

Panics

If the allocator fails to provide an appropriate allocation.

pub fn new(value: T) -> Self

Attempts to allocate Self and store value in it.

Panics

If the allocator fails to provide an appropriate allocation.

Source

impl<T, Alloc: IAlloc> Arc<T, Alloc>

pub unsafe fn try_make_in<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, alloc: Alloc, ) -> Result<Self, Result<Arc<MaybeUninit<T>, Alloc>, (F, Alloc)>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

If the constructor panics, the allocated memory will be leaked.

Errors
  • Returns the constructor and the allocator in case of allocation failure.
  • Returns the uninitialized allocated memory if constructor fails.
Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Notes

Note that the allocation may or may not be zeroed.

pub fn try_new_in(value: T, alloc: Alloc) -> Result<Self, (T, Alloc)>

Attempts to allocate a Self and store value in it

Errors

Returns value and the allocator in case of failure.

pub unsafe fn make_in<F: for<'a> FnOnce(&'a mut MaybeUninit<T>) -> Result<&'a mut T, ()>>( constructor: F, alloc: Alloc, ) -> Result<Self, Arc<MaybeUninit<T>, Alloc>>

Attempts to allocate Self, initializing it with constructor.

Note that the allocation may or may not be zeroed.

Errors

Returns the uninitialized allocated memory if constructor fails.

Safety

constructor MUST return Err(()) if it failed to initialize the passed argument.

Panics

If the allocator fails to provide an appropriate allocation.

pub fn new_in(value: T, alloc: Alloc) -> Self

Attempts to allocate Self and store value in it.

Panics

If the allocator fails to provide an appropriate allocation.

pub const fn into_raw(this: Self) -> AllocPtr<T, Alloc>

Returns the pointer to the inner raw allocation, leaking this.

Note that the pointer may be dangling if T is zero-sized.

pub const unsafe fn from_raw(this: AllocPtr<T, Alloc>) -> Self

Constructs Self from a raw allocation.

Safety

this MUST not be dangling, and have been obtained through Self::into_raw.

pub fn get_mut(this: &mut Self) -> Option<&mut T>

Provides a mutable reference to the internals if the strong and weak counts are both 1.

pub const unsafe fn get_mut_unchecked(this: &mut Self) -> &mut T

Provides a mutable reference to the internals without checking.

Safety

If used carelessly, this can cause mutable references and immutable references to the same value to appear, causing undefined behaviour.

pub fn strong_count(this: &Self) -> usize

Returns the strong count.

pub unsafe fn increment_strong_count(this: *const T) -> usize

Increments the strong count.

Safety

this MUST be a valid pointer derived from Self

pub fn weak_count(this: &Self) -> usize

Returns the weak count. Note that all Arcs to a same value share a Weak, so the weak count can never be 0.

pub fn increment_weak_count(this: &Self) -> usize

Increments the weak count, returning its previous value.

pub fn make_mut(&mut self) -> &mut T
where T: Clone, Alloc: Clone,

Returns a mutable reference to this Arc’s value, cloning that value into a new Arc if Self::get_mut would have failed.

pub fn make_mut_and_get_alloc(&mut self) -> (&mut T, &Alloc)
where T: Clone, Alloc: Clone,

Returns a mutable reference to this Arc’s value, cloning that value into a new Arc if Self::get_mut would have failed.

pub fn is_unique(this: &Self) -> bool

Whether or not this is the sole owner of its data, including weak owners.

pub fn try_into_inner(this: Self) -> Result<T, Self>

Attempts the value from the allocation, freeing said allocation.

Errors

Returns this if it’s not the sole owner of its value.

pub fn downgrade(this: &Self) -> Weak<T, Alloc>

Constructs an additional Weak pointer to this.

pub const fn allocator(this: &Self) -> &Alloc

Returns a reference to the allocator used to construct this