Struct AtomicArc

#[repr(C)]
pub struct AtomicArc<T, Alloc: IAlloc> { /* private fields */ }
An owner of an Arc<T, Alloc> whose pointee can be atomically changed.

Implementations

Source

impl<T, Alloc: IAlloc> AtomicArc<T, Alloc>

pub const fn has_optimal_layout() -> bool

Returns true if the layout for AtomicArc is smaller or equal to that Rust would have generated for it.

Source

impl<T, Alloc: IAlloc> AtomicArc<T, Alloc>

pub const fn new(value: Option<Arc<T, Alloc>>) -> Self

Constructs a new AtomicArc set to the provided value.

pub fn load(&self, order: Ordering) -> Option<Arc<T, Alloc>>

Atomically load the current value.

pub fn store(&self, value: Option<Arc<T, Alloc>>, order: Ordering)

Atomically store a new value.

pub fn is( &self, current: Option<&Arc<T, Alloc>>, order: Ordering, ) -> Result<(), Option<Arc<T, Alloc>>>

Compares self with current by pointer.

Errors

Returns the new value of self if it differs from current.

pub fn compare_exchange( &self, current: Option<&Arc<T, Alloc>>, new: Option<Arc<T, Alloc>>, success: Ordering, failure: Ordering, ) -> Result<Option<Arc<T, Alloc>>, Option<Arc<T, Alloc>>>

Replace the current value with the new value.

Errors

If current no longer points to the same value as self, it