#[repr(C)]pub struct Weak<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }Expand description
alloc::sync::Weak, but ABI-stable.
Implementations
Sourceimpl<T, Alloc: IAlloc> Weak<T, Alloc>
impl<T, Alloc: IAlloc> Weak<T, Alloc>
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for Weak is smaller or equal to that Rust would have generated for it.
Sourceimpl<T, Alloc: IAlloc> Weak<T, Alloc>
impl<T, Alloc: IAlloc> Weak<T, Alloc>
Sourcepub const fn into_raw(this: Self) -> AllocPtr<T, Alloc>
pub const fn into_raw(this: Self) -> AllocPtr<T, Alloc>
Returns the pointer to the inner raw allocation, leaking this.
Note that the pointer may be dangling if T is zero-sized.
Sourcepub const unsafe fn from_raw(this: AllocPtr<T, Alloc>) -> Self
pub const unsafe fn from_raw(this: AllocPtr<T, Alloc>) -> Self
Constructs Self from a raw allocation.
Safety
this MUST not be dangling, and have been obtained through Self::into_raw.