#[repr(C)]pub struct WeakSlice<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }Expand description
A weak reference counted slice.
Implementations
Sourceimpl<T, Alloc: IAlloc> WeakSlice<T, Alloc>
impl<T, Alloc: IAlloc> WeakSlice<T, Alloc>
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for WeakSlice is smaller or equal to that Rust would have generated for it.
Sourceimpl<T, Alloc: IAlloc> WeakSlice<T, Alloc>
impl<T, Alloc: IAlloc> WeakSlice<T, Alloc>
Sourcepub fn upgrade(&self) -> Option<ArcSlice<T, Alloc>>
pub fn upgrade(&self) -> Option<ArcSlice<T, Alloc>>
Return a strong reference to the slice if it hasn’t been destroyed yet.
Sourcepub fn force_upgrade(&self) -> ArcSlice<T, Alloc>where
T: Copy,
pub fn force_upgrade(&self) -> ArcSlice<T, Alloc>where
T: Copy,
For types that are Copy, the slice actually remains valid even after all strong references
have been dropped as long as at least a weak reference lives on.
If you’re using this, there are probably design issues in your program…