#[repr(transparent)]pub struct NotPod<T>(pub T);Expand description
Strips T of its status as Plain Old Data.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: IStable> IStable for NotPod<T>
impl<T: IStable> IStable for NotPod<T>
Sourceconst REPORT: &'static TypeReport
const REPORT: &'static TypeReport
A compile-time generated report of the fields of the type, allowing for compatibility inspection.
Sourceconst ID: u64
const ID: u64
A stable (and ideally unique) identifier for the type. Often generated using
crate::report::gen_id, but can be manually set.Sourcetype ContainsIndirections = B1
type ContainsIndirections = B1
Whether or not the type contains indirections (pointers, indices in independent data-structures…)
Sourcetype ForbiddenValues = <T as IStable>::ForbiddenValues
type ForbiddenValues = <T as IStable>::ForbiddenValues
The values that the annotated type cannot occupy.
Sourcetype HasExactlyOneNiche = <T as IStable>::HasExactlyOneNiche
type HasExactlyOneNiche = <T as IStable>::HasExactlyOneNiche
Allows the detection of whether or not
core::option::Options are stable: Read moreSourcetype UnusedBits = <T as IStable>::UnusedBits
type UnusedBits = <T as IStable>::UnusedBits
The padding bits in the annotated types
Sourceimpl<T: Ord> Ord for NotPod<T>
impl<T: Ord> Ord for NotPod<T>
Sourceimpl<T: PartialOrd> PartialOrd for NotPod<T>
impl<T: PartialOrd> PartialOrd for NotPod<T>
impl<T: Copy> Copy for NotPod<T>
impl<T: Eq> Eq for NotPod<T>
impl<T> StructuralPartialEq for NotPod<T>