pub struct NonXIsize<const FORBIDDEN: isize> { /* private fields */ }Expand description
A number whose value is guaranteed not to be FORBIDDEN.
x is stored as NonZero(x.wrapping_sub(FORBIDDEN)), so transmuting results in wrong values.
Implementations
Sourceimpl<const FORBIDDEN: isize> NonXIsize<FORBIDDEN>
impl<const FORBIDDEN: isize> NonXIsize<FORBIDDEN>
Sourcepub const fn new(n: isize) -> Option<Self>
pub const fn new(n: isize) -> Option<Self>
Construct Self, returning None if n is the FORBIDDEN value.
Sourcepub const unsafe fn new_unchecked(n: isize) -> Self
pub const unsafe fn new_unchecked(n: isize) -> Self
Constructs Self without checking whether or not it is only 1s.
Safety
Calling this with the illegal value may result in undefined behaviour.