Struct TypeReport

#[repr(C)]
pub struct TypeReport { pub name: Str<'static>, pub module: Str<'static>, pub fields: StableLike<Option<&'static FieldReport>, usize>, pub tyty: TyTy, pub version: u32, }
A report of a type’s layout.

Fields

name: Str<'static>

The type’s name.

module: Str<'static>

The type’s parent module’s path.

fields: StableLike<Option<&'static FieldReport>, usize>

The fields of this type.

tyty: TyTy

How the type was declared

version: u32

The version of the type’s invariants.

Implementations

Source

impl TypeReport

pub const fn has_optimal_layout() -> bool

Returns true if the layout for TypeReport is smaller or equal to that Rust would have generated for it.

Source

impl TypeReport

pub fn is_compatible(&self, other: &Self) -> bool

Whether or not two reports correspond to the same type, with the same layout and invariants.

Source

impl TypeReport

pub const fn fields(&self) -> Fields

Returns an iterator over the type’s fields.