Struct VTable

#[repr(C)]
pub struct VTable<Head, Tail = VtDrop> { pub tail: Tail, pub head: Head, }
A recursive type to define sets of v-tables. You should always use stabby::vtable!(Trait1 + Trait2 + ...) to generate this type, as this macro will ensure that traits are ordered consistently in the vtable.

Fields

tail: Tail

The rest of the vtable.

It comes first to allow upcasting vtables.

head: Head

The head of the vtable (the last trait listed in the macros)

Implementations

Source

impl<Head, Tail> VTable<Head, Tail>
where Struct<FieldPair<Tail, Head>>: IStable, Head: IStable, Tail: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for VTable is smaller or equal to that Rust would have generated for it.