#[repr(C)]pub struct RustAlloc { /* private fields */ }Expand description
Rust’s GlobalAlloc, annotating its yielded pointers in such a way that the allocated pointers can be safely freed from other binaries.
Implementations