#[repr(C)]pub struct AtomicArc<T, Alloc: IAlloc> { /* private fields */ }Expand description
An owner of an Arc<T, Alloc> whose pointee can be atomically changed.
Implementations
Sourceimpl<T, Alloc: IAlloc> AtomicArc<T, Alloc>where
Struct<FieldPair<AtomicPtr<T>, PhantomData<*const Alloc>>>: IStable,
PhantomData<*const Alloc>: IStable,
AtomicPtr<T>: IStable,
impl<T, Alloc: IAlloc> AtomicArc<T, Alloc>where
Struct<FieldPair<AtomicPtr<T>, PhantomData<*const Alloc>>>: IStable,
PhantomData<*const Alloc>: IStable,
AtomicPtr<T>: IStable,
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for AtomicArc is smaller or equal to that Rust would have generated for it.
Sourceimpl<T, Alloc: IAlloc> AtomicArc<T, Alloc>
impl<T, Alloc: IAlloc> AtomicArc<T, Alloc>
Sourcepub const fn new(value: Option<Arc<T, Alloc>>) -> Self
pub const fn new(value: Option<Arc<T, Alloc>>) -> Self
Constructs a new AtomicArc set to the provided value.
Sourcepub fn load(&self, order: Ordering) -> Option<Arc<T, Alloc>>
pub fn load(&self, order: Ordering) -> Option<Arc<T, Alloc>>
Atomically load the current value.
Sourcepub fn store(&self, value: Option<Arc<T, Alloc>>, order: Ordering)
pub fn store(&self, value: Option<Arc<T, Alloc>>, order: Ordering)
Atomically store a new value.
Sourcepub fn is(
&self,
current: Option<&Arc<T, Alloc>>,
order: Ordering,
) -> Result<(), Option<Arc<T, Alloc>>>
pub fn is( &self, current: Option<&Arc<T, Alloc>>, order: Ordering, ) -> Result<(), Option<Arc<T, Alloc>>>
Compares self with current by pointer.
Errors
Returns the new value of self if it differs from current.
Sourcepub fn compare_exchange(
&self,
current: Option<&Arc<T, Alloc>>,
new: Option<Arc<T, Alloc>>,
success: Ordering,
failure: Ordering,
) -> Result<Option<Arc<T, Alloc>>, Option<Arc<T, Alloc>>>
pub fn compare_exchange( &self, current: Option<&Arc<T, Alloc>>, new: Option<Arc<T, Alloc>>, success: Ordering, failure: Ordering, ) -> Result<Option<Arc<T, Alloc>>, Option<Arc<T, Alloc>>>
Replace the current value with the new value.
Errors
If current no longer points to the same value as self, it