Struct Weak

#[repr(C)]
pub struct Weak<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }
alloc::sync::Weak, but ABI-stable.

Implementations

Source

impl<T, Alloc: IAlloc> Weak<T, Alloc>
where Struct<AllocPtr<T, Alloc>>: IStable, AllocPtr<T, Alloc>: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for Weak is smaller or equal to that Rust would have generated for it.

Source

impl<T, Alloc: IAlloc> Weak<T, Alloc>

pub const fn into_raw(this: Self) -> AllocPtr<T, Alloc>

Returns the pointer to the inner raw allocation, leaking this.

Note that the pointer may be dangling if T is zero-sized.

pub const unsafe fn from_raw(this: AllocPtr<T, Alloc>) -> Self

Constructs Self from a raw allocation.

Safety

this MUST not be dangling, and have been obtained through Self::into_raw.

pub fn upgrade(&self) -> Option<Arc<T, Alloc>>

Attempts to upgrade self into an Arc.