Struct WeakSlice

#[repr(C)]
pub struct WeakSlice<T, Alloc: IAlloc = DefaultAllocator> { /* private fields */ }
A weak reference counted slice.

Implementations

Source

impl<T, Alloc: IAlloc> WeakSlice<T, Alloc>
where Struct<AllocSlice<T, Alloc>>: IStable, AllocSlice<T, Alloc>: IStable,

pub const fn has_optimal_layout() -> bool

Returns true if the layout for WeakSlice is smaller or equal to that Rust would have generated for it.

Source

impl<T, Alloc: IAlloc> WeakSlice<T, Alloc>

pub fn upgrade(&self) -> Option<ArcSlice<T, Alloc>>

Return a strong reference to the slice if it hasn’t been destroyed yet.

pub fn force_upgrade(&self) -> ArcSlice<T, Alloc>
where T: Copy,

For types that are Copy, the slice actually remains valid even after all strong references have been dropped as long as at least a weak reference lives on.

If you’re using this, there are probably design issues in your program…