#[repr(C)]pub struct TypeReport {
pub name: Str<'static>,
pub module: Str<'static>,
pub fields: StableLike<Option<&'static FieldReport>, usize>,
pub tyty: TyTy,
pub version: u32,
}Expand description
A report of a type’s layout.
Fields
name: Str<'static>The type’s name.
module: Str<'static>The type’s parent module’s path.
fields: StableLike<Option<&'static FieldReport>, usize>The fields of this type.
tyty: TyTyHow the type was declared
version: u32The version of the type’s invariants.
Implementations
Sourceimpl TypeReport
impl TypeReport
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for TypeReport is smaller or equal to that Rust would have generated for it.
Sourceimpl TypeReport
impl TypeReport
Sourcepub fn is_compatible(&self, other: &Self) -> bool
pub fn is_compatible(&self, other: &Self) -> bool
Whether or not two reports correspond to the same type, with the same layout and invariants.